@@ -125,12 +125,15 @@ class JobBuilder():
 
     @log_dir.setter
     def log_dir(self, val):
+        """
         self._log_dir = val
         if hpogrid.is_local_job() and (not os.path.isabs(val)):
             project_path = helper.get_project_path(self.project_name)
             if os.path.exists(project_path):
                 self._log_dir = os.path.join(project_path, val)
         self._log_dir = helper.pretty_path(self._log_dir)
+        """
+        self._log_dir = val
             
         
             
@@ -155,6 +158,7 @@ class JobBuilder():
         self._log_dir = kDefaultLogDir
         self.stop = kDefaultStopping
         self._resource = None
+        self.extra_metrics = None
         # parameters for logging
         self._df = None
         self._start_datetime = None
@@ -273,6 +277,8 @@ class JobBuilder():
         cols_to_save = ['time_s'] + self.hyperparameters
         if 'metric' in summary:
             cols_to_save.append(summary['metric'])
+        if self.extra_metrics:
+            cols_to_save += self.extra_metrics
         df = df.filter(cols_to_save, axis=1).transpose()
         summary['result'] = df.to_dict()
 
@@ -339,8 +345,8 @@ class JobBuilder():
                 datadir = hpogrid.get_datadir()
                 extracted_files = helper.extract_tarball(datadir, datadir)
                 
-            ray.init(include_dashboard=False,
-                     lru_evict=True)
+            ray.init(include_dashboard=False)
+#           lru_evict=True            
             analysis = tune.run(
                 model,
                 name=self.project_name,
@@ -352,9 +358,9 @@ class JobBuilder():
                 verbose=self.verbose,
                 local_dir=self.log_dir,
                 loggers=loggers,
-                stop=self.stop,
-                sync_to_driver=False,
-                global_checkpoint_period=np.inf)
+                stop=self.stop)
+#                sync_to_driver=False,
+#                global_checkpoint_period=np.inf)
         finally:
             ray.shutdown()
             # remove the extracted tar files
@@ -371,7 +377,7 @@ class JobBuilder():
         
         print("INFO: Ray Tune log files are saved at {}".format(self.log_dir))
 
-        df = analysis.dataframe()
+        df = analysis.dataframe(metric=self.metric, mode=self.mode)
 
         metadata = self.create_metadata(df)
         
@@ -396,10 +402,12 @@ class JobBuilder():
     
     def get_metadata_path(self):
         base_path = hpogrid.get_workdir()
+        """
         if hpogrid.is_local_job():
             project_path = helper.get_project_path(self.project_name)
             if os.path.exists(project_path):
                 base_path = project_path
+        """
         metadata_path = os.path.join(base_path, kGridSiteMetadataFileName)
         return metadata_path
     
@@ -442,7 +450,7 @@ class JobBuilder():
         job.log_dir = config['hpo_config']['log_dir']
         job.stop = config['hpo_config'].get('stop', None)
         job.resource_per_trial = config['hpo_config'].get('resource', None)
-        
+        job.extra_metrics = config['hpo_config'].get('extra_metrics', None)
         
         # configuration for idds
         if (not search_points) and hpogrid.is_idds_job():
