@@ -25,6 +25,9 @@ class HPOConfiguration(ConfigurationBase):
             parser.add_argument('-m', '--metric', metavar='',
                                 help='Evaluation metric to be optimized',
                                 required=True)
+            parser.add_argument('-e', '--extra_metrics', metavar='', nargs='+',
+                                help='Additional metrics to be saved during the training',
+                                required=False)
             parser.add_argument('-o', '--mode', 
                                 help='Mode of optimization (either "min" or "max")', 
                                 choices=kMetricMode,
